@@ -14,10 +14,9 @@ class JSONFormatter(_JSONFormatter):
         :param record: `LogRecord` we got from `JSONFormatter.format()`.
         :return: Dictionary which will be passed to JSON lib.
         """
-        print(record.__dict__)
         extra['msg'] = message
         if 'logcreated' not in extra:
-            extra['logcreated'] = record.created + 9 * 3600
+            extra['logcreated'] = record.created
 
         if 'logname' not in extra:
             extra['logname'] = record.name
